@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Module::CoreList;
 
-our $VERSION = '5.20250803';
+our $VERSION = '5.20250923';
 our %utilities;
 
 sub utilities {
@@ -2182,6 +2182,20 @@ my %delta = (
         removed => {
         }
     },
+    5.043002 => {
+        delta_from => 5.043001,
+        changed => {
+        },
+        removed => {
+        }
+    },
+    5.043003 => {
+        delta_from => 5.043002,
+        changed => {
+        },
+        removed => {
+        }
+    },
 );
 
 %utilities = Module::CoreList::_undelta(\%delta);
